==> ejc-proother-api-3.0.0-20220329.124038-22-sources.jar: com/ejianc/business/settle/vo/SettleOtherVO.java <==
package com.ejianc.business.settle.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 结算 其他费用
 * 
 * @author generator
 * 
 */
public class SettleOtherVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Integer useFlag; // 是否引用过,否-0，是-1
    private Long settleId; // 结算id
    private String sourceType; // 来源:合同内，合同外
    private Long contractId; // 合同id
    private Long projectId; // 项目Id
    private Long sourceId; // 其他费用id
    private String costName; // 费用项
    private BigDecimal costTaxRate; // 税率
    private BigDecimal taxMny; // 本期结算金额，本期结算金额=本期结算量*单价
    private BigDecimal mny; // 本期结算金额(无税)
    private BigDecimal tax; // 本期结算税额
    private String memo; // 备注
    private Integer settleType;

    public Integer getSettleType() {
        return settleType;
    }

    public void setSettleType(Integer settleType) {
        this.settleType = settleType;
    }

    public Long getSettleId() {
        return settleId;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }
    public BigDecimal getCostTaxRate() {
        return costTaxRate;
    }

    public void setCostTaxRate(BigDecimal costTaxRate) {
        this.costTaxRate = costTaxRate;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-proother-api-3.0.0-20220520.060328-71-sources.jar: com/ejianc/business/settle/vo/SettleOtherVO.java <==
package com.ejianc.business.settle.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 结算 其他费用
 * 
 * @author generator
 * 
 */
public class SettleOtherVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Integer useFlag; // 是否引用过,否-0，是-1
    private Long settleId; // 结算id
    private String sourceType; // 来源:合同内，合同外
    private Long contractId; // 合同id
    private Long projectId; // 项目Id
    private Long sourceId; // 其他费用id
    private String costName; // 费用项
    private BigDecimal costTaxRate; // 税率
    private BigDecimal taxMny; // 本期结算金额，本期结算金额=本期结算量*单价
    private BigDecimal mny; // 本期结算金额(无税)
    private BigDecimal tax; // 本期结算税额
    private String memo; // 备注
    private Integer settleType;
    private Long otherWbsId; // 核算对象主键
    private String otherWbsName; // 核算对象名称
    private String otherWbsCode; // 核算对象编码
    private Long otherSubjectId; // 成本科目主键
    private String otherSubjectName; // 成本科目名称
    private String otherSubjectCode; // 成本科目编码

    public Long getOtherWbsId() {
        return otherWbsId;
    }

    public void setOtherWbsId(Long otherWbsId) {
        this.otherWbsId = otherWbsId;
    }

    public String getOtherWbsName() {
        return otherWbsName;
    }

    public void setOtherWbsName(String otherWbsName) {
        this.otherWbsName = otherWbsName;
    }

    public String getOtherWbsCode() {
        return otherWbsCode;
    }

    public void setOtherWbsCode(String otherWbsCode) {
        this.otherWbsCode = otherWbsCode;
    }

    public Long getOtherSubjectId() {
        return otherSubjectId;
    }

    public void setOtherSubjectId(Long otherSubjectId) {
        this.otherSubjectId = otherSubjectId;
    }

    public String getOtherSubjectName() {
        return otherSubjectName;
    }

    public void setOtherSubjectName(String otherSubjectName) {
        this.otherSubjectName = otherSubjectName;
    }

    public String getOtherSubjectCode() {
        return otherSubjectCode;
    }

    public void setOtherSubjectCode(String otherSubjectCode) {
        this.otherSubjectCode = otherSubjectCode;
    }

    public Integer getSettleType() {
        return settleType;
    }

    public void setSettleType(Integer settleType) {
        this.settleType = settleType;
    }

    public Long getSettleId() {
        return settleId;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }
    public BigDecimal getCostTaxRate() {
        return costTaxRate;
    }

    public void setCostTaxRate(BigDecimal costTaxRate) {
        this.costTaxRate = costTaxRate;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
